==> members-facade-2.2.12-20220228.093450-5-sources.jar: com/bizvane/members/facade/constants/SysResponseEnum.java <==
package com.bizvane.members.facade.constants;

/**
 * @author chen.li
 * @date on 2018/6/21 10:30
 * @description 系统响应返回码枚举类，此处定义所有该系统对外响应的返回码及释义
 * @version 1.0
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public enum SysResponseEnum {
    SUCCESS(0, "操作成功！"),
    SYSTEM_NOT_LOGIN(-2, "未登录！"),

    FAILED(100, "操作失败！"),

    OPERATE_FAILED_DATA_NOT_EXISTS(101, "查询数据不存在！"),
    SYSTEM_DATA_NOT_EMPTY(118, "数据不能为空！"),
    OPERATE_FAILED_ADD_ERROR(102, "新增数据失败！"),
    OPERATE_FAILED_UPDATE_ERROR(103, "更新数据失败！"),
    OPERATE_FAILED_FILE_NOT_EXISTS(104, "操作失败，文件不存在！"),
    OPERATE_FAILED_FILE_UPLOAD_ERROR(105, "操作失败，文件上传错误！"),
    USER_LOGIN_FAILED_VALIDATECODE_NOT_EXISTS(106, "验证码不存在！"),
    USER_LOGIN_FAILED_VALIDATECODE_ERROR(107, "验证码错误！"),
    USER_LOGIN_SMS_CODE_OVERTIME(108, "短信验证码已过期！"),
    USER_LOGIN_FAILED_USERID_NOT_EXISTS(109, "登录失败，用户名不存在！"),
    USER_BIND_THIRD_LOGIN_ERROR(110, "登录失败，用户被禁用！"),
    USER_LOGIN_FAILED_USER_DISABLE(111, "登录失败，密码错误！"),
    USER_UPDATE_ERROR(112, "修改用户失败！"),
    USER_MIBILE_NOT_EXIST(113, "该手机号不存在！"),
    NETWORK_ERROR(114,"网络异常！"),
    SYSTEM_ERROR(115,"系统内部错误！"),
    SYSTEM_ERROR_DATA(11555,"系统内部错误！"),
    UPLOAD_SUCCESS(116,"导入成功！"),
    UPLOAD_FAILED(117,"导入失败！"),
    REPEAT_FAILED(118,"正在执行，稍后再试！"),
    REDUPLICATE_STORE(120,"店铺群组不能重复！"),
    REDUPLICATE_PAYTYPE(121,"该支付类型已存在重复！"),
    RATIOS_NOT_ZERO(121,"比例不能小于等于0！"),
    REDUPLICATE_INTEGRARATIO(122,"等级积分配置重复！");


    private int code;

    private String message;

    SysResponseEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    public int getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

}

==> members-facade-20250930-20250911.094123-7-sources.jar: com/bizvane/members/facade/constants/SysResponseEnum.java <==
package com.bizvane.members.facade.constants;

/**
 * @author chen.li
 * @date on 2018/6/21 10:30
 * @description 系统响应返回码枚举类，此处定义所有该系统对外响应的返回码及释义
 * @version 1.0
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public enum SysResponseEnum {
    SUCCESS(0, "操作成功！"),
    SYSTEM_NOT_LOGIN(-2, "未登录！"),

    FAILED(100, "操作失败！"),

    OPERATE_FAILED_DATA_NOT_EXISTS(101, "查询数据不存在！"),
    SYSTEM_DATA_NOT_EMPTY(118, "数据不能为空！"),
    OPERATE_FAILED_ADD_ERROR(102, "新增数据失败！"),
    OPERATE_FAILED_UPDATE_ERROR(103, "更新数据失败！"),
    OPERATE_FAILED_FILE_NOT_EXISTS(104, "操作失败，文件不存在！"),
    OPERATE_FAILED_FILE_UPLOAD_ERROR(105, "操作失败，文件上传错误！"),
    USER_LOGIN_FAILED_VALIDATECODE_NOT_EXISTS(106, "验证码不存在！"),
    USER_LOGIN_FAILED_VALIDATECODE_ERROR(107, "验证码错误！"),
    USER_LOGIN_SMS_CODE_OVERTIME(108, "短信验证码已过期！"),
    USER_LOGIN_FAILED_USERID_NOT_EXISTS(109, "登录失败，用户名不存在！"),
    USER_BIND_THIRD_LOGIN_ERROR(110, "登录失败，用户被禁用！"),
    USER_LOGIN_FAILED_USER_DISABLE(111, "登录失败，密码错误！"),
    USER_UPDATE_ERROR(112, "修改用户失败！"),
    USER_MIBILE_NOT_EXIST(113, "该手机号不存在！"),
    NETWORK_ERROR(114,"网络异常！"),
    SYSTEM_ERROR(115,"系统内部错误！"),
    SYSTEM_ERROR_DATA(11555,"系统内部错误！"),
    UPLOAD_SUCCESS(116,"导入成功！"),
    UPLOAD_FAILED(117,"导入失败！"),
    REPEAT_FAILED(118,"正在执行，稍后再试！"),
    REDUPLICATE_STORE(120,"店铺群组不能重复！"),
    REDUPLICATE_PAYTYPE(121,"该支付类型已存在重复！"),
    RATIOS_NOT_ZERO(121,"比例不能小于等于0！"),
    REDUPLICATE_INTEGRARATIO(122,"等级积分配置重复！"),
    //会员小程序开绑卡失败场景，弹用户主动确定弹窗
    USER_APPLET_BINDING_CARD_FAIL_WINDOW(123,"会员小程序开绑卡失败场景弹窗提示");


    private int code;

    private String message;

    SysResponseEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    public int getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

}
